using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Android.App;
using Android.Content;
using Android.OS;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using System.IO;
using System.Xml;
using System.Net;

namespace RsssAndroidApp
{
    public class RssViewModel
    {
        private static RssViewModel _rssViewModel;
        private RssViewModel() { } // disable new....
        //static RssViewModel()
        //{
        //    _rssViewModel = new RssViewModel();
        //}
        public static RssViewModel Model
        {
            get
            {
                if (_rssViewModel == null)
                {
                    _rssViewModel = new RssViewModel();
                }
                return _rssViewModel;
            }
        }
        private List<RssItem> _Items;
        public List<RssItem> Items
        {
            get
            {
                if (_Items == null)
                    _Items = new List<RssItem>();
                return _Items;
            }
        }
        public RssItem SelectedItem { get; set; }
        public bool IsLoaded { get; set; }
        public delegate void LoadCompletedEventType();
        public event LoadCompletedEventType OnLoadCompleted;

        public void LoadTestItems()
        {
            Items.Add(new RssItem() { Title = "Titel 1", PubDate = "2017.03.08" });
            _Items.Add(new RssItem() { Title = "Titel 2", PubDate = "2017.03.09" });

        }

        public void LoadXmlNewsFromAsset(Activity context)
        {
            Stream input = context.Assets.Open("view-source_www.dr.dk_Nyheder_Service_feeds_regionale_fyn_.xml");
            StreamReader reader = new StreamReader(input);
            string xmlText = reader.ReadToEnd();

            LoadXmlNewsFromText(xmlText);
        }
        public void LoadXmlNewsFromText(string xmlText)
        {
            XmlDocument xdoc = new XmlDocument();
            xdoc.LoadXml(xmlText);
            IsLoaded = false;
            Items.Clear();

            XmlNodeList xmlItems =
                xdoc.SelectNodes("/rss/channel/item");
            foreach (var xmlItem in xmlItems)
            {
                XmlElement xelm = xmlItem as XmlElement;
                RssItem item = new RssItem();
                item.Title = xelm.GetElementsByTagName("title")[0].InnerText;
                item.Description = xelm.GetElementsByTagName("description")[0].InnerText;
                item.Link = xelm.GetElementsByTagName("link")[0].InnerText;
                item.PubDate = xelm.GetElementsByTagName("pubDate")[0].InnerText;
                Items.Add(item);
            }
            IsLoaded = true;
            if (OnLoadCompleted != null)
                OnLoadCompleted();

        }
        public void LoadNewsFromRssFeed()
        {
            string urlAdresse = "http://www.dr.dk/nyheder/service/feeds/vejret";

            WebClient wclient = new WebClient();
            wclient.DownloadStringCompleted += Wclient_DownloadStringCompleted;
            Uri uri = new Uri(urlAdresse);
            wclient.DownloadStringAsync(uri);
        }

        private void Wclient_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            if (e.Error == null)
            {
                var res = e.Result;
                LoadXmlNewsFromText(e.Result);
            }
            else
                Android.Util.Log.Error("", e.Error.Message);
        }
    }
}